@@ -1,7 +1,7 @@
 #!/usr/local/bin/python2.7
 # -*- coding: utf-8 -*-
 ###############################################################################
-# $Id: gdal_edit.py 27044 2014-03-16 23:41:27Z rouault $
+# $Id: gdal_edit.py 29248 2015-05-25 09:57:17Z rouault $
 #
 #  Project:  GDAL samples
 #  Purpose:  Edit in place various information of an existing GDAL dataset
@@ -35,9 +35,10 @@ from osgeo import osr
 
 def Usage():
     print('Usage: gdal_edit [--help-general] [-ro] [-a_srs srs_def] [-a_ullr ulx uly lrx lry]')
-    print('                 [-tr xres yres] [-unsetgt] [-a_nodata value] ')
+    print('                 [-tr xres yres] [-unsetgt] [-a_nodata value]')
+    print('                 [-unsetstats] [-stats] [-approx_stats]')
     print('                 [-gcp pixel line easting northing [elevation]]*')
-    print('                 [-mo "META-TAG=VALUE"]*  datasetname')
+    print('                 [-unsetmd] [-oo NAME=VALUE]* [-mo "META-TAG=VALUE"]*  datasetname')
     print('')
     print('Edit in place various information of an existing GDAL dataset.')
     return -1
@@ -69,9 +70,14 @@ def gdal_edit(argv):
     xres = None
     yres = None
     unsetgt = False
+    unsetstats = False
+    stats = False
+    approx_stats = False
+    unsetmd = False
     ro = False
     molist = []
     gcp_list = []
+    open_options = []
 
     i = 1
     argc = len(argv)
@@ -119,6 +125,18 @@ def gdal_edit(argv):
             gcp_list.append(gcp)
         elif argv[i] == '-unsetgt' :
             unsetgt = True
+        elif argv[i] == '-unsetstats':
+            unsetstats = True
+        elif argv[i] == '-approx_stats':
+            stats = True
+            approx_stats = True
+        elif argv[i] == '-stats':
+            stats = True
+        elif argv[i] == '-unsetmd':
+            unsetmd = True
+        elif argv[i] == '-oo' and i < len(argv)-1:
+            open_options.append(argv[i+1])
+            i = i + 1
         elif argv[i][0] == '-':
             sys.stderr.write('Unrecognized option : %s\n' % argv[i])
             return Usage()
@@ -133,7 +151,9 @@ def gdal_edit(argv):
     if datasetname is None:
         return Usage()
 
-    if srs is None and lry is None and yres is None and not unsetgt and nodata is None and len(molist) == 0:
+    if (srs is None and lry is None and yres is None and not unsetgt
+            and not unsetstats and not stats and nodata is None
+            and len(molist) == 0 and not unsetmd and len(gcp_list) == 0):
         print('No option specified')
         print('')
         return Usage()
@@ -150,7 +170,18 @@ def gdal_edit(argv):
         print('')
         return Usage()
 
-    if ro:
+    if unsetstats and stats:
+        print('-unsetstats and either -stats or -approx_stats options are exclusive.')
+        print('')
+        return Usage()
+
+    if open_options is not None:
+        if ro:
+            ds = gdal.OpenEx(datasetname, gdal.OF_RASTER, open_options = open_options)
+        else:
+            ds = gdal.OpenEx(datasetname, gdal.OF_RASTER | gdal.OF_UPDATE, open_options = open_options)
+    # GDAL 1.X compat
+    elif ro:
         ds = gdal.Open(datasetname)
     else:
         ds = gdal.Open(datasetname, gdal.GA_Update)
@@ -177,7 +208,7 @@ def gdal_edit(argv):
     if yres is not None:
         gt = ds.GetGeoTransform()
         # Doh ! why is gt a tuple and not an array...
-        gt = [ gt[i] for i in range(6) ]
+        gt = [ gt[j] for j in range(6) ]
         gt[1] = xres
         gt[5] = yres
         ds.SetGeoTransform(gt)
@@ -194,12 +225,33 @@ def gdal_edit(argv):
 
     if nodata is not None:
         for i in range(ds.RasterCount):
-            ds.GetRasterBand(1).SetNoDataValue(nodata)
+            ds.GetRasterBand(i+1).SetNoDataValue(nodata)
+
+    if unsetstats:
+        for i in range(ds.RasterCount):
+            band = ds.GetRasterBand(i+1)
+            for key in band.GetMetadata().keys():
+                if key.startswith('STATISTICS_'):
+                    band.SetMetadataItem(key, None)
+
+    if stats:
+        for i in range(ds.RasterCount):
+            ds.GetRasterBand(i+1).ComputeStatistics(approx_stats)
 
     if len(molist) != 0:
-        ds.SetMetadata(molist)
+        if unsetmd:
+            md = {}
+        else:
+            md = ds.GetMetadata()
+        for moitem in molist:
+            equal_pos = moitem.find('=')
+            if equal_pos > 0:
+                md[moitem[0:equal_pos]] = moitem[equal_pos+1:]
+        ds.SetMetadata(md)
+    elif unsetmd:
+        ds.SetMetadata({})
 
-    ds = None
+    ds = band = None
 
     return 0
 
